Python Color Math Module (colormath)
====================================

:Author: Greg Taylor
:License: BSD

What is it?
-----------

This module implements a large number of different color operations such as
color space conversions, Delta E, and density to spectral.

Why?
----

Public documentation for color math is very limited, and there were no Python
color math libraries with even a fraction of the common routines implemented.

Requirements
------------

colormath requires NumPy, which you may get from:
 
    http://numpy.scipy.org/

Or via pip/easy_install::

    pip install numpy

Installation
------------

The easiest way to install colormath is via pip/easy_install::

    pip install colormath

Alternatively, download and extract the package from PyPi at
http://pypi.python.org/pypi/colormath/, then extract and run the installer
directly::

  python setup.py install
  
Documentation
-------------

For documentation, see the project webpage at:

    http://code.google.com/p/python-colormath/
    
There are also a lot of useful examples under the examples directory within
this directory.

Support
-------

Head over to https://github.com/gtaylor/python-colormath
and submit an issue if you have any problems or questions.

Legal Mumbo Jumbo
-----------------

Copyright (C) 2012 Gregory Taylor

This software is licensed under the BSD License.
